import sys
import typing

GenericType = typing.TypeVar("GenericType")


def url_prefill_from_blender(addon_info):
    ''' 

    '''

    pass
